==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V2beta2ExternalMetricStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V2beta2ExternalMetricStatusFluentImpl<A extends V2beta2ExternalMetricStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V2beta2ExternalMetricStatusFluent<A>{

    private V2beta2MetricValueStatusBuilder current;
    private V2beta2MetricIdentifierBuilder metric;

    public V2beta2ExternalMetricStatusFluentImpl(){
    }
    public V2beta2ExternalMetricStatusFluentImpl(V2beta2ExternalMetricStatus instance){
            this.withCurrent(instance.getCurrent());

            this.withMetric(instance.getMetric());

    }

    
/**
 * This method has been deprecated, please use method buildCurrent instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2MetricValueStatus getCurrent(){
            return this.current!=null?this.current.build():null;
    }

    public V2beta2MetricValueStatus buildCurrent(){
            return this.current!=null?this.current.build():null;
    }

    public A withCurrent(V2beta2MetricValueStatus current){
            _visitables.remove(this.current);
            if (current!=null){ this.current= new V2beta2MetricValueStatusBuilder(current); _visitables.add(this.current);} return (A) this;
    }

    public Boolean hasCurrent(){
            return this.current != null;
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> withNewCurrent(){
            return new CurrentNestedImpl();
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> withNewCurrentLike(V2beta2MetricValueStatus item){
            return new CurrentNestedImpl(item);
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> editCurrent(){
            return withNewCurrentLike(getCurrent());
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrent(){
            return withNewCurrentLike(getCurrent() != null ? getCurrent(): new V2beta2MetricValueStatusBuilder().build());
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(V2beta2MetricValueStatus item){
            return withNewCurrentLike(getCurrent() != null ? getCurrent(): item);
    }

    
/**
 * This method has been deprecated, please use method buildMetric instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2MetricIdentifier getMetric(){
            return this.metric!=null?this.metric.build():null;
    }

    public V2beta2MetricIdentifier buildMetric(){
            return this.metric!=null?this.metric.build():null;
    }

    public A withMetric(V2beta2MetricIdentifier metric){
            _visitables.remove(this.metric);
            if (metric!=null){ this.metric= new V2beta2MetricIdentifierBuilder(metric); _visitables.add(this.metric);} return (A) this;
    }

    public Boolean hasMetric(){
            return this.metric != null;
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> withNewMetric(){
            return new MetricNestedImpl();
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> withNewMetricLike(V2beta2MetricIdentifier item){
            return new MetricNestedImpl(item);
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> editMetric(){
            return withNewMetricLike(getMetric());
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> editOrNewMetric(){
            return withNewMetricLike(getMetric() != null ? getMetric(): new V2beta2MetricIdentifierBuilder().build());
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> editOrNewMetricLike(V2beta2MetricIdentifier item){
            return withNewMetricLike(getMetric() != null ? getMetric(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V2beta2ExternalMetricStatusFluentImpl that = (V2beta2ExternalMetricStatusFluentImpl) o;
            if (current != null ? !current.equals(that.current) :that.current != null) return false;
            if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
            return true;
    }


    public class CurrentNestedImpl<N> extends V2beta2MetricValueStatusFluentImpl<V2beta2ExternalMetricStatusFluent.CurrentNested<N>> implements V2beta2ExternalMetricStatusFluent.CurrentNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2MetricValueStatusBuilder builder;
    
            CurrentNestedImpl(V2beta2MetricValueStatus item){
                    this.builder = new V2beta2MetricValueStatusBuilder(this, item);
            }
            CurrentNestedImpl(){
                    this.builder = new V2beta2MetricValueStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2ExternalMetricStatusFluentImpl.this.withCurrent(builder.build());
    }
    public N endCurrent(){
            return and();
    }

}
    public class MetricNestedImpl<N> extends V2beta2MetricIdentifierFluentImpl<V2beta2ExternalMetricStatusFluent.MetricNested<N>> implements V2beta2ExternalMetricStatusFluent.MetricNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2MetricIdentifierBuilder builder;
    
            MetricNestedImpl(V2beta2MetricIdentifier item){
                    this.builder = new V2beta2MetricIdentifierBuilder(this, item);
            }
            MetricNestedImpl(){
                    this.builder = new V2beta2MetricIdentifierBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2ExternalMetricStatusFluentImpl.this.withMetric(builder.build());
    }
    public N endMetric(){
            return and();
    }

}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta2ExternalMetricStatusFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.Deprecated;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class V2beta2ExternalMetricStatusFluentImpl<A extends V2beta2ExternalMetricStatusFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V2beta2ExternalMetricStatusFluent<A>{

    private V2beta2MetricValueStatusBuilder current;
    private V2beta2MetricIdentifierBuilder metric;

    public V2beta2ExternalMetricStatusFluentImpl(){
    }
    public V2beta2ExternalMetricStatusFluentImpl(V2beta2ExternalMetricStatus instance){
            this.withCurrent(instance.getCurrent());

            this.withMetric(instance.getMetric());

    }

    
/**
 * This method has been deprecated, please use method buildCurrent instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2MetricValueStatus getCurrent(){
            return this.current!=null?this.current.build():null;
    }

    public V2beta2MetricValueStatus buildCurrent(){
            return this.current!=null?this.current.build():null;
    }

    public A withCurrent(V2beta2MetricValueStatus current){
            _visitables.get("current").remove(this.current);
            if (current!=null){ this.current= new V2beta2MetricValueStatusBuilder(current); _visitables.get("current").add(this.current);} return (A) this;
    }

    public Boolean hasCurrent(){
            return this.current != null;
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> withNewCurrent(){
            return new CurrentNestedImpl();
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> withNewCurrentLike(V2beta2MetricValueStatus item){
            return new CurrentNestedImpl(item);
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> editCurrent(){
            return withNewCurrentLike(getCurrent());
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrent(){
            return withNewCurrentLike(getCurrent() != null ? getCurrent(): new V2beta2MetricValueStatusBuilder().build());
    }

    public V2beta2ExternalMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(V2beta2MetricValueStatus item){
            return withNewCurrentLike(getCurrent() != null ? getCurrent(): item);
    }

    
/**
 * This method has been deprecated, please use method buildMetric instead.
 * @return The buildable object.
 */
@Deprecated public V2beta2MetricIdentifier getMetric(){
            return this.metric!=null?this.metric.build():null;
    }

    public V2beta2MetricIdentifier buildMetric(){
            return this.metric!=null?this.metric.build():null;
    }

    public A withMetric(V2beta2MetricIdentifier metric){
            _visitables.get("metric").remove(this.metric);
            if (metric!=null){ this.metric= new V2beta2MetricIdentifierBuilder(metric); _visitables.get("metric").add(this.metric);} return (A) this;
    }

    public Boolean hasMetric(){
            return this.metric != null;
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> withNewMetric(){
            return new MetricNestedImpl();
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> withNewMetricLike(V2beta2MetricIdentifier item){
            return new MetricNestedImpl(item);
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> editMetric(){
            return withNewMetricLike(getMetric());
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> editOrNewMetric(){
            return withNewMetricLike(getMetric() != null ? getMetric(): new V2beta2MetricIdentifierBuilder().build());
    }

    public V2beta2ExternalMetricStatusFluent.MetricNested<A> editOrNewMetricLike(V2beta2MetricIdentifier item){
            return withNewMetricLike(getMetric() != null ? getMetric(): item);
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V2beta2ExternalMetricStatusFluentImpl that = (V2beta2ExternalMetricStatusFluentImpl) o;
            if (current != null ? !current.equals(that.current) :that.current != null) return false;
            if (metric != null ? !metric.equals(that.metric) :that.metric != null) return false;
            return true;
    }


    public class CurrentNestedImpl<N> extends V2beta2MetricValueStatusFluentImpl<V2beta2ExternalMetricStatusFluent.CurrentNested<N>> implements V2beta2ExternalMetricStatusFluent.CurrentNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2MetricValueStatusBuilder builder;
    
            CurrentNestedImpl(V2beta2MetricValueStatus item){
                    this.builder = new V2beta2MetricValueStatusBuilder(this, item);
            }
            CurrentNestedImpl(){
                    this.builder = new V2beta2MetricValueStatusBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2ExternalMetricStatusFluentImpl.this.withCurrent(builder.build());
    }
    public N endCurrent(){
            return and();
    }

}
    public class MetricNestedImpl<N> extends V2beta2MetricIdentifierFluentImpl<V2beta2ExternalMetricStatusFluent.MetricNested<N>> implements V2beta2ExternalMetricStatusFluent.MetricNested<N>,io.kubernetes.client.fluent.Nested<N>{

            private final V2beta2MetricIdentifierBuilder builder;
    
            MetricNestedImpl(V2beta2MetricIdentifier item){
                    this.builder = new V2beta2MetricIdentifierBuilder(this, item);
            }
            MetricNestedImpl(){
                    this.builder = new V2beta2MetricIdentifierBuilder(this);
            }
    
    public N and(){
            return (N) V2beta2ExternalMetricStatusFluentImpl.this.withMetric(builder.build());
    }
    public N endMetric(){
            return and();
    }

}


}
